Module python

Module python 

Structs

AddExpression
AndExpression
AndExpressionForCompare
BitAndExpression
BitOrExpression
BitXorExpression
ConstantBool
ConstantBytes
ConstantComplex
ConstantEllipsis
ConstantFloat
ConstantInt
ConstantNone
ConstantString
ConstantTuple
DivExpression
EqualExpression
FloorDivExpression
GreaterThanExpression
GreaterThanOrEqualExpression
IfWithElse
IfWithoutElse
InExpression
InvertExpression
IsExpression
IsNotExpression
LShiftExpression
LessThanExpression
LessThanOrEqualExpression
LiteralBytes
MatMultExpression
ModExpression
MultExpression
NotEqualExpression
NotExpression
NotInExpression
OrExpression
PowExpression
Python
PythonFormats
The formatting to use for each feature of the programming language. Features for which no formatting is specified here, will use the formatting specified in the first parent who specifies a format for this feature.
PythonInputNoArgument
PythonInputWithOneArgument
PythonPrintWithMultipleArguments
PythonPrintWithOneArgument
RShiftExpression
SubExpression
UnaryAddExpression
UnarySubExpression

Enums

PythonAliasPlaceholder
PythonAnnotatedAssignPlaceholder
PythonArgumentPlaceholder
PythonArgumentWithDefaultPlaceholder
PythonArgumentsPlaceholder
PythonAssertPlaceholder
PythonAssignPlaceholder
PythonAsyncForPlaceholder
PythonAsyncFunctionDefPlaceholder
PythonAsyncWithPlaceholder
PythonAttributePlaceholder
PythonAugmentedAssignPlaceholder
PythonAwaitPlaceholder
PythonCallPlaceholder
PythonClassDefPlaceholder
PythonComprehensionPlaceholder
PythonConstantBoolPlaceholder
PythonConstantBytesPlaceholder
PythonConstantComplexPlaceholder
PythonConstantExpressionPlaceholder
PythonConstantFloatPlaceholder
PythonConstantIntegerPlaceholder
PythonConstantStringPlaceholder
PythonConstantTuplePlaceholder
PythonDeletePlaceholder
PythonDictComprehensionPlaceholder
PythonDictExprPlaceholder
PythonEqualPlaceholder
PythonExceptHandlerPlaceholder
PythonExprAddPlaceholder
PythonExprAndPlaceholder
PythonExprBitAndPlaceholder
PythonExprBitOrPlaceholder
PythonExprBitXorPlaceholder
PythonExprDivPlaceholder
PythonExprFloorDivPlaceholder
PythonExprInvertPlaceholder
PythonExprLShiftPlaceholder
PythonExprMatMultPlaceholder
PythonExprModPlaceholder
PythonExprMultPlaceholder
PythonExprNotPlaceholder
PythonExprOrPlaceholder
PythonExprPowPlaceholder
PythonExprRShiftPlaceholder
PythonExprSubPlaceholder
PythonExprUnaryAddPlaceholder
PythonExprUnarySubPlaceholder
PythonExpressionStatementPlaceholder
PythonForPlaceholder
PythonFormatsField
PythonFormatsFilledField
PythonFormattedValuePlaceholder
PythonFunctionDefPlaceholder
PythonGeneratorComprehensionPlaceholder
PythonGlobalPlaceholder
PythonGreaterThanOrEqualPlaceholder
PythonGreaterThanPlaceholder
PythonIdentifierPlaceholder
PythonIfExprPlaceholder
PythonIfWithElsePlaceholder
PythonIfWithoutElsePlaceholder
PythonImportFromPlaceholder
PythonImportPlaceholder
PythonInPlaceholder
PythonInputWithOneArgumentPlaceholder
PythonIsNotPlaceholder
PythonIsPlaceholder
PythonJoinedStringPlaceholder
PythonKeywordPlaceholder
PythonLambdaPlaceholder
PythonLessThanOrEqualPlaceholder
PythonLessThanPlaceholder
PythonListComprehensionPlaceholder
PythonListPlaceholder
PythonMatchCasePlaceholder
PythonMatchPlaceholder
PythonNamePlaceholder
PythonNamedExprPlaceholder
PythonNonLocalPlaceholder
PythonNotEqualPlaceholder
PythonNotInPlaceholder
PythonPrintWithMultipleArgumentsPlaceholder
PythonPrintWithOneArgumentPlaceholder
PythonRaisePlaceholder
PythonReturnPlaceholder
PythonSetComprehensionPlaceholder
PythonSetExprPlaceholder
PythonSlicePlaceholder
PythonStarredPlaceholder
PythonSubscriptPlaceholder
PythonTryPlaceholder
PythonTryStarPlaceholder
PythonTuplePlaceholder
PythonTypeAliasPlaceholder
PythonWhilePlaceholder
PythonWithItemPlaceholder
PythonWithPlaceholder
PythonYieldFromPlaceholder
PythonYieldPlaceholder

Functions

example_format

Type Aliases

PythonBreakPlaceholder
PythonConstantEllipsisPlaceholder
PythonConstantNonePlaceholder
PythonContinuePlaceholder
PythonParseError
PythonPassPlaceholder