pub enum PythonClassDefPlaceholder {
Name,
Bases,
Keywords,
Body,
DecoratorList,
TypeParams,
}Variants
Name
The name of the class
Bases
a list of nodes for explicitly specified base classes
Keywords
a list of keyword nodes, principally for ‘metaclass’. Other keywords will be passed to the metaclass, as per PEP 3115.
Body
The body of the class
DecoratorList
The list of decorators to be applied, stored outermost first (i.e. the first in the list will be applied last).
TypeParams
A list of type parameters