Structs
- AddExpression
- AndExpression
- AndExpression
ForCompare - BitAnd
Expression - BitOr
Expression - BitXor
Expression - Constant
Bool - Constant
Bytes - Constant
Complex - Constant
Ellipsis - Constant
Float - Constant
Int - Constant
None - Constant
String - Constant
Tuple - DivExpression
- Equal
Expression - Floor
DivExpression - Greater
Than Expression - Greater
Than OrEqual Expression - IfWith
Else - IfWithout
Else - InExpression
- Invert
Expression - IsExpression
- IsNot
Expression - LShift
Expression - Less
Than Expression - Less
Than OrEqual Expression - Literal
Bytes - MatMult
Expression - ModExpression
- Mult
Expression - NotEqual
Expression - NotExpression
- NotIn
Expression - OrExpression
- PowExpression
- Python
- Python
Formats - The formatting to use for each feature of the programming language. Features for which no formatting is specified here, will use the formatting specified in the first parent who specifies a format for this feature.
- Python
Input NoArgument - Python
Input With OneArgument - Python
Print With Multiple Arguments - Python
Print With OneArgument - RShift
Expression - SubExpression
- Unary
AddExpression - Unary
SubExpression
Enums
- Python
Alias Placeholder - Python
Annotated Assign Placeholder - Python
Argument Placeholder - Python
Argument With Default Placeholder - Python
Arguments Placeholder - Python
Assert Placeholder - Python
Assign Placeholder - Python
Async ForPlaceholder - Python
Async Function DefPlaceholder - Python
Async With Placeholder - Python
Attribute Placeholder - Python
Augmented Assign Placeholder - Python
Await Placeholder - Python
Call Placeholder - Python
Class DefPlaceholder - Python
Comprehension Placeholder - Python
Constant Bool Placeholder - Python
Constant Bytes Placeholder - Python
Constant Complex Placeholder - Python
Constant Expression Placeholder - Python
Constant Float Placeholder - Python
Constant Integer Placeholder - Python
Constant String Placeholder - Python
Constant Tuple Placeholder - Python
Delete Placeholder - Python
Dict Comprehension Placeholder - Python
Dict Expr Placeholder - Python
Equal Placeholder - Python
Except Handler Placeholder - Python
Expr AddPlaceholder - Python
Expr AndPlaceholder - Python
Expr BitAnd Placeholder - Python
Expr BitOr Placeholder - Python
Expr BitXor Placeholder - Python
Expr DivPlaceholder - Python
Expr Floor DivPlaceholder - Python
Expr Invert Placeholder - Python
ExprL Shift Placeholder - Python
Expr MatMult Placeholder - Python
Expr ModPlaceholder - Python
Expr Mult Placeholder - Python
Expr NotPlaceholder - Python
Expr OrPlaceholder - Python
Expr PowPlaceholder - Python
ExprR Shift Placeholder - Python
Expr SubPlaceholder - Python
Expr Unary AddPlaceholder - Python
Expr Unary SubPlaceholder - Python
Expression Statement Placeholder - Python
ForPlaceholder - Python
Formats Field - Python
Formats Filled Field - Python
Formatted Value Placeholder - Python
Function DefPlaceholder - Python
Generator Comprehension Placeholder - Python
Global Placeholder - Python
Greater Than OrEqual Placeholder - Python
Greater Than Placeholder - Python
Identifier Placeholder - Python
IfExpr Placeholder - Python
IfWith Else Placeholder - Python
IfWithout Else Placeholder - Python
Import From Placeholder - Python
Import Placeholder - Python
InPlaceholder - Python
Input With OneArgument Placeholder - Python
IsNot Placeholder - Python
IsPlaceholder - Python
Joined String Placeholder - Python
Keyword Placeholder - Python
Lambda Placeholder - Python
Less Than OrEqual Placeholder - Python
Less Than Placeholder - Python
List Comprehension Placeholder - Python
List Placeholder - Python
Match Case Placeholder - Python
Match Placeholder - Python
Name Placeholder - Python
Named Expr Placeholder - Python
NonLocal Placeholder - Python
NotEqual Placeholder - Python
NotIn Placeholder - Python
Print With Multiple Arguments Placeholder - Python
Print With OneArgument Placeholder - Python
Raise Placeholder - Python
Return Placeholder - Python
SetComprehension Placeholder - Python
SetExpr Placeholder - Python
Slice Placeholder - Python
Starred Placeholder - Python
Subscript Placeholder - Python
TryPlaceholder - Python
TryStar Placeholder - Python
Tuple Placeholder - Python
Type Alias Placeholder - Python
While Placeholder - Python
With Item Placeholder - Python
With Placeholder - Python
Yield From Placeholder - Python
Yield Placeholder