pub type PythonParseError = LanguageParseError<ParseError>;Aliased Type
pub enum PythonParseError {
ParserError,
Custom(BaseError<ParseErrorType>),
}Variants
ParserError
The parser used for the language seems to do something wrong.
Custom(BaseError<ParseErrorType>)
An error given by the parser of the language